<?php

/*
 * Version 0.1, 26th October 2011
 * Jason Milad Daivandy (j.daivandy@fz-juelich.de)
*/
class SSOAgent {

	protected $host;
	protected $port;	
	protected $sso_service_path = '/sso-service';
	protected $res_session = '/session';
	protected $res_session_roles_and_credentials = '/session/roles_and_credentials';
	protected $res_credential = '/credential';
	protected $res_session_timeout = '/session/timeout';
	protected $base_url;

	function SSOAgent($host, $port) {
		$this->host = $host;
		$this->port = $port;
		$this->httpClient = curl_init();
		$this->base_url = "http://".$this->host.":".$this->port.$this->sso_service_path;
	}

	function login($username, $password) {
		$headers  =  array( "Content-type: application/json" );
		$input = array( "USER_NAME"=>$username, "PASSWORD"=>$password);
		$ch = curl_init();
		curl_setopt ($ch, CURLOPT_URL, $this->base_url.$this->res_session);
		curl_setopt($ch, CURLOPT_POST, 1);
		curl_setopt ($ch, CURLOPT_HTTPHEADER, $headers);
		curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($input));
		curl_setopt($ch, CURLOPT_RETURNTRANSFER,1);

		$result = curl_exec($ch);
		curl_close ($ch);
		$sessionId = json_decode($result, false)->{"SSO_SESSION_ID"};	
		
		return $sessionId;
	}

	function refreshSession($sessionId) {
		$ch = curl_init();
		$headers  =  array( "Accept: application/json" );
		curl_setopt ($ch, CURLOPT_URL, $this->base_url."/".$sessionId.$this->res_session."/refresh");
		curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "GET");
		curl_setopt ($ch, CURLOPT_HTTPHEADER, $headers);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER,1);

		$result = curl_exec($ch);
		$httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
		curl_close ($ch);
		
		return $httpCode;
	}

	function logout($sessionId) {
		$ch = curl_init();
		$headers  =  array( "Accept: application/json");
		curl_setopt ($ch, CURLOPT_URL, $this->base_url."/".$sessionId.$this->res_session);
		curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "DELETE");
		curl_setopt ($ch, CURLOPT_HTTPHEADER, $headers);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER,1);

		$result = curl_exec($ch);

		curl_close ($ch);

		$loggedOut = json_decode($result, false)->{"IS_LOGGED_OUT"};

		return $loggedOut;
	}

	function addCredential($sessionId, $credentialAssocArray) {
		$ch = curl_init();
		$headers  =  array( "Content-type: application/json" );
		$credentialJSON = json_encode($credentialAssocArray);
		curl_setopt ($ch, CURLOPT_URL, $this->base_url."/".$sessionId."/".$this->res_credential);
		curl_setopt($ch, CURLOPT_POST, 1);
		curl_setopt ($ch, CURLOPT_HTTPHEADER, $headers);
		curl_setopt($ch, CURLOPT_POSTFIELDS, $credentialJSON);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER,1);

		$result = curl_exec($ch);

		curl_close ($ch);
	}

	function getCredential($sessionId, $credential) {
		$credentialArray = $this->getCredentials($sessionId, array($credential));
		if(isset($credentialArray))
			return $credentialArray[0];
		
		else
			return null;
	}

	function getCredentials($sessionId, $credentials) {
		$requestedCredentials = '';				

		if($credentials!='all') {	
			for($i=0; $i<sizeof($credentials); $i++) {			
			$cred = $credentials[$i];
			if($i<sizeof($credentials)-1)
				$cred = $cred.',';

			$requestedCredentials = $requestedCredentials.$cred;			
			}
		}		

		else
			$requestedCredentials = 'all';
			
		$ch = curl_init();
		$headers  =  array( "Accept: application/json" );
		curl_setopt ($ch, CURLOPT_URL, $this->base_url."/".$sessionId.$this->res_credential."/".$requestedCredentials);
		print("credNames=".$requestedCredentials."<br>");
		print("url=".$this->base_url."/".$sessionId.$this->res_credential."/".$requestedCredentials);
		curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "GET");
		curl_setopt ($ch, CURLOPT_HTTPHEADER, $headers);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER,1);

		$result = curl_exec($ch);
		curl_close ($ch);

		$credentialsAssocArray = json_decode($result, true);

		return $credentialsAssocArray;
	}

	function removeCredential($sessionId, $credentialName) {
		$ch = curl_init();
		$headers  =  array( "Accept: application/json");
		curl_setopt ($ch, CURLOPT_URL, $this->base_url."/".$sessionId.$this->res_credential."/".$credentialName);
		curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "DELETE");
		curl_setopt ($ch, CURLOPT_HTTPHEADER, $headers);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER,1);

		$result = curl_exec($ch);

		curl_close ($ch);


	}
}

?>